TitanItemCount = LibStub("AceAddon-3.0"):NewAddon("TitanItemCount", "AceConsole-3.0", "AceComm-3.0", "AceEvent-3.0", "AceSerializer-3.0", "AceTimer-3.0");
TitanItemCount.version = "50200-1.02.2";
TitanItemCount.author = "Solage of Greymane";

local menutext = "Titan Item Count |cff22ee55(" .. GetAddOnMetadata("TitanItemCount", "Version") .. ")";
local buttonlabel = "Item Count: "
local ID = "ItmC"
local elapItmC, ItmC, prevItmC = 0, 0.0, -2
local GetUnitItmC = 0 
local startVal = 0
local inInstance, instanceType, instanceStarted
local CurrencyIndex
local OrigItemToCount

TitanItemCount_UpdateInterval = 1.0;


--[[
-- ------------------[ Settings for the Addon Options Panel ]---------------
]]--

local options = {
	name = "Item Count",
	handler = TitanItemCount,
	type = "group",
	args = {
		info1 = {
			type		= "description",
			name		= "Version " .. TitanItemCount.version,
			order		= 0,
		},
		info2 = {
			type		= "description",
			name		= "Authors: " .. TitanItemCount.author,
			order		= 1,
		},
		header = {
			type		= "header",
			name		= "General Options",
			order		= 2,
		},
		ItemToCount = {
			type = 'input',
			name = "Item to Count",
			desc = "The inventory item for which you want to track the current quantity carried in your bags.",
			get = function() return TitanItemCount.db.char.ItemToCount end,
			set = "SetItemToCount",
		}
	}
};


--[[
-- ------------------[ Saved Variable Data Table ]---------------
]]--

local defaults = {
	char = {
		ItemToCount = "Elixir of Water Walking",
	}
};


--[[
-- ------------------[ Addon Object Functions ]---------------
]]--

function TitanItemCount:OnInitialize()
	-- Load Options DB
	self.db = LibStub("AceDB-3.0"):New("TitanItemCountDB", defaults);

	-- Initialize Config Panels
	self:InitConfig();

   -- Register Events

	-- Delay welcome message.
	self:ScheduleTimer(function() 
			self:Print("Titan Item Count (ver. " .. self.version .. ") is loaded.  Currently tracking [".. TitanItemCount.db.char.ItemToCount .."]  Use /tic to change tracked item.")
		end, 4);

end


function TitanItemCount:InitConfig()

	LibStub("AceConfig-3.0"):RegisterOptionsTable("Item Count", options);
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions("Item Count");

end


function TitanItemCount:SetItemToCount(info, input)
   TitanItemCount:ticAnnounce(input)
   TitanItemCount.db.char.ItemToCount = input
end


function TitanItemCount:ticAnnounce(msg)
   print(GREEN_FONT_COLOR_CODE .. "Counted Item changed to " .. msg)
end


--[[
-- ------------------[ Titan Panel Button Event handlers ]---------------
]]--

function TitanPanelItmCButton_OnUpdate(this, elapsed)
   if elapsed == nil then elapsed = 2; end
   elapItmC = elapItmC + elapsed;
   if elapItmC < 1 then return end
   
   ItmC = GetItemCount(TitanItemCount.db.char.ItemToCount)
   
   if ItmC == prevItmC then return end
   prevItmC = ItmC
   TitanPanelButton_UpdateButton(ID)
   elapItmC = 0;
end


function TitanPanelItmCButton_OnLoad(self)
   if not TitanPanelButton_UpdateButton then
      return;
   end

	self.registry = {
		id = ID,
		menuText = menutext,
		buttonTextFunction = "TitanPanelItmCButton_GetButtonText",
		tooltipTitle = GREEN_FONT_COLOR_CODE .. "Item Count",
		tooltipTextFunction = "TitanPanelItmCButton_GetTooltipText",
		frequency = 2,
		icon = "Interface\\AddOns\\TitanBag\\TitanBag",
		iconWidth = 16,
		category = "Information",
		savedVariables = {
			ShowIcon = 1,
			ShowLabelText = false,
		},
	}

end


function TitanPanelItmCButton_OnShow(self)
	TitanPanelButton_OnShow(self);
end


function TitanPanelItmCButton_OnHide()
end


function TitanPanelItmCButton_OnClick(self, button)
   if (button == "LeftButton") then
      InterfaceOptionsFrame_OpenToCategory("Item Count")
   end
end


function TitanPanelItmCButton_GetButtonText()
	local ItmCtext, pitchtext
	if not ItmC then
		ItmCtext = "0"
	else	
		if startVal == count or startVal == 0 then
			ItmCtext = string.format(" %.0f", ItmC) .."" 
		else
			if ItmC - startVal == 0 then
				ItmCtext = string.format(" %.0f", ItmC) .."" 
			else
				ItmCtext = string.format(" %.0f", ItmC) .." (+".. ItmC - startVal..")"
	      end
	      return buttonlabel, ItmCtext
      end
	end
	return buttonlabel, ItmCtext
end


function TitanPanelItmCButton_GetTooltipText()
	return "Quantity of ".. TitanItemCount.db.char.ItemToCount .." in your inventory"
end


--[[
-- ------------------[ No Idea what This Stuff Does ]---------------
]]--

local temp = {}
local function UIDDM_Add(text, func, checked, keepShown)
	temp.text, temp.func, temp.checked, temp.keepShownOnClick = text, func, checked, keepShown
	UIDropDownMenu_AddButton(temp)
end
function TitanPanelRightClickMenu_PrepareItmCMenu()
	TitanPanelRightClickMenu_AddTitle(TitanPlugins[ID].menuText)	
	TitanPanelRightClickMenu_AddToggleIcon(ID)
	TitanPanelRightClickMenu_AddToggleLabelText(ID)
	TitanPanelRightClickMenu_AddSpacer()
	TitanPanelRightClickMenu_AddCommand(TITAN_PANEL_MENU_HIDE, ID, TITAN_PANEL_MENU_FUNC_HIDE)
end

--[[
-- ------------------[ Slash Command Handling ]---------------
]]--

SLASH_ITMCOUNT1 = "/tic";
function SlashCmdList.ITMCOUNT(msg)
   -- try getting count of item
   local icount = GetItemCount(msg)
   if icount > 0 then
      TitanItemCount.db.char.ItemToCount = msg
      TitanItemCount:ticAnnounce(msg)
      startVal = 0
   else
      print(YELLOW_FONT_COLOR_CODE.."Titan Item Count -- SYNTAX: |cff33DDFF/tic Item Name"..YELLOW_FONT_COLOR_CODE.." (The Item must exist in your inventory)")
   end
end

